@@ -40,6 +40,7 @@
 #include <QtGui/QImage>
 #include <QtGui/QPainter>
 #include <QtGui/QPixmap>
+#include <QMimeDatabase>
 
 //#include <kcodecs.h>
 #include <QUrl>
@@ -483,12 +484,8 @@ QImage ThumbnailProtocol::thumbForDirectory(const QUrl& directory)
     // TODO: the margins are optimized for the Oxygen iconset
     // Provide a fallback solution for other iconsets (e. g. draw folder
     // only as small overlay, use no margins)
-
-    //Use the current (custom) folder icon
-    QUrl tempDirectory = directory;
-    tempDirectory.setScheme("file"); //iconNameForUrl will not work with the "thumbnail:/" scheme
-    //QString iconName = KMimeType::findByUrl(tempDirectory)
-    QString iconName = "plasma"; // FIXME
+    const QMimeDatabase db;
+    const QString iconName = db.mimeTypeForName("inode/directory").iconName();
 
     const QPixmap folder = KIconLoader::global()->loadMimeTypeIcon(iconName,
                                                                    KIconLoader::Desktop,
